pub fn init_metrics()Expand description
Force all Lazy statics to initialise and record the build-info gauge.
Call this once from crate::run_server before the server starts accepting
connections.
pub fn init_metrics()Force all Lazy statics to initialise and record the build-info gauge.
Call this once from crate::run_server before the server starts accepting
connections.