pub struct CosMapItem {
pub host: String,
pub port: u16,
pub region: Option<String>,
pub api_key: Option<String>,
pub access_key: Option<String>,
pub secret_key: Option<String>,
pub ttl: Option<u64>,
pub tls: Option<bool>,
pub addressing_style: Option<String>,
}Expand description
Represents a COS map item with its properties.
This struct is used to store the configuration for a COS bucket. Each bucket is identified by its name, and the properties include:
host: The host address of the COS service.port: The port number for the COS service.region: The region where the COS service is located.api_key: The API key for accessing the COS service (optional).access_key: The access key for the COS service (optional).secret_key: The secret key for the COS service (optional).ttl: The time-to-live for the COS bucket (optional).
Fields
host: Stringport: u16region: Option<String>api_key: Option<String>access_key: Option<String>secret_key: Option<String>ttl: Option<u64>tls: Option<bool>addressing_style: Option<String>Implementations
Sourceimpl CosMapItem
impl CosMapItem
Sourcepub fn has_api_key(&self) -> bool
pub fn has_api_key(&self) -> bool
Returns true if an API‑key is present.
Sourcepub async fn ensure_credentials<F, Fut>(
&mut self,
bucket: &str,
fetcher: Option<F>,
) -> Result<(), Box<dyn Error + Send + Sync>>
pub async fn ensure_credentials<F, Fut>( &mut self, bucket: &str, fetcher: Option<F>, ) -> Result<(), Box<dyn Error + Send + Sync>>
Ensure that some credential (HMAC or API key) is populated.
- If HMAC pair exists → OK
- Else if api_key exists → OK
- Else it calls the supplied async
fetcher(bucket)which should return one of the accepted formats (seeBucketCredential). The struct is then updated in‑place.