pub struct ProxyServerConfig {
pub bucket_creds_fetcher: Option<Py<PyAny>>,
pub cos_map: PyObject,
pub http_port: Option<u16>,
pub https_port: Option<u16>,
pub validator: Option<Py<PyAny>>,
pub threads: Option<usize>,
pub verify: Option<bool>,
pub hmac_keystore: PyObject,
pub skip_signature_validation: Option<bool>,
pub hmac_fetcher: Option<Py<PyAny>>,
pub max_presign_url_usage_attempts: Option<usize>,
pub server_name: String,
}Expand description
Configuration object for :pyfunc:object_storage_proxy.start_server.
Parameters
cos_map: A dictionary mapping bucket names to their respective COS configuration. Each entry should contain the following keys:
- host: The COS endpoint (e.g., “s3.eu-de.cloud-object-storage.appdomain.cloud”)
- port: The port number (e.g., 443)
- api_key/apikey: The API key for the bucket (optional)
- ttl/time-to-live: The time-to-live for the API key in seconds (optional)
bucket_creds_fetcher: Optional Python async callable that fetches the API key for a bucket. The callable should accept a single argument, the bucket name. It should return a string containing the API key. http_port: The HTTP port to listen on. https_port: The HTTPS port to listen on. validator: Optional Python async callable that validates the request. The callable should accept two arguments, the token and the bucket name. It should return a boolean indicating whether the request is valid. threads: Optional number of threads to use for the server. If not specified, the server will use a single thread.
Fields
bucket_creds_fetcher: Option<Py<PyAny>>cos_map: PyObjecthttp_port: Option<u16>https_port: Option<u16>validator: Option<Py<PyAny>>threads: Option<usize>verify: Option<bool>hmac_keystore: PyObjectskip_signature_validation: Option<bool>hmac_fetcher: Option<Py<PyAny>>max_presign_url_usage_attempts: Option<usize>server_name: StringImplementations
Sourceimpl ProxyServerConfig
impl ProxyServerConfig
pub fn new( cos_map: PyObject, hmac_keystore: Option<PyObject>, bucket_creds_fetcher: Option<PyObject>, http_port: Option<u16>, https_port: Option<u16>, validator: Option<PyObject>, threads: Option<usize>, verify: Option<bool>, skip_signature_validation: Option<bool>, hmac_fetcher: Option<PyObject>, max_presign_url_usage_attempts: Option<usize>, server_name: String, ) -> Self
pub(crate) fn __repr__(&self) -> PyResult<String>